bc4py extension
====
Extension library of bc4py implemented by Rust.

Requirement
----
* Rust nightly version
* python3 and setuptools-rust
* [bc4py_plotter](https://github.com/namuyan/bc4py_plotter)

Install
----
Require pre-install Rust-nightly.
```text
pip3 install --user setuptools-rust
pip3 install --user git+https://github.com/namuyan/bc4py_extension
```

Licence
----
MIT

Auther
----
[namuyan_mine](http://twitter.com/namuyan_mine)
